@@ -181,7 +181,7 @@ def random_shuffle(notes: List[int], **kwargs) -> List[int]:
 
 
 def random_octaves(
-    notes: List[int], octaves: List[int], prob_octave: int = 25, **kwargs
+    notes: List[int], octaves: List[int] = [1], prob_octave: int = 33, **kwargs
 ) -> List[int]:
     """
     randomly apply octaves to a sequence
